def ranger():
    import os
    command='export TERM=linux && \
    export TERMINFO=/bin/sh && \
    ranger --copy-config=all && \
    sudo -H -u who ranger --copy-config=all'
    os.system(command)




def editor():
    import os
    command='echo "cd ~ \ngit clone https://github.com/whohe/.vim\n\
    ln -s .vim/vimrc .vimrc \ncd ~/.vim \n\
    git submodule update --init --recursive \n\
    cd /home/who \ngit clone https://github.com/whohe/.vim\n\
    ln -s .vim/vimrc .vimrc \n cd /home/who/.vim \n\
    git submodule update --init --recursive " >> /tmp/deploy_editor.sh && \
    sh /tmp/deploy_editor.sh && \
    sudo -H -u who sh /tmp/deploy_editor.sh \
    rm /tmp/deploy_editor.sh' 
    os.system(command)



def git():
    import os
    command='cd ~ && \
    wget https://gist.githubusercontent.com/whohe/9bf4574b1d2d00a613e2/raw/8bfcdf01d14f4088ca15248a76212988255763a1/.gitconfig && \
    cp .gitconfig /home/who/. && chown who:who .gitconfig'
    os.system(command)




def fish():
    import os
    command='mkdir -p ~/.config/fish && \
    echo "export LC_ALL=es_CO.UTF-8" >> ~/.config/fish/config.fish && \
    echo "export EDITOR=vim" >> ~/.config/fish/config.fish && \
    cp ~/.config && /home/who/.config -r && chown who:who .gitconfig -R'
    os.system(command)



def multiplexer():
    import os
    command='echo "cd ~ \nmkdir -p .byobu \n\
    git clone https://github.com/whohe/.tmux ~/.tmux --branch master-fish \n\
    ln -s .tmux/tmux.conf .tmux.conf \ncd .tmux \n\
    git submodule update --init --recursive \ncd ~/.byobu \n\
    ln -s ../.tmux.conf . " > /tmp/deploy_multiplexer.sh \n\
    sh /tmp/deploy_multiplexer.sh && \
    sudo -H -u who sh /tmp/deploy_multiplexer.sh \
    rm /tmp/deploy_multiplexer.sh'
    os.system(command)

